@@ -76,7 +76,8 @@ class RopeBackend(NativeBackend):
             return None
         project = self.projects.get(project_root)
         if project is None:
-            project = self.projectlib.Project(project_root)
+            project = self.projectlib.Project(project_root,
+                                              ropefolder=None)
             self.projects[project_root] = project
         last_validation = self.last_validation.get(project_root, 0.0)
         now = time.time()
@@ -132,6 +133,9 @@ class RopeBackend(NativeBackend):
                                              "s" if ("," in linedesc)
                                              else "",
                                              linedesc)))
+        except IndentationError:
+            raise rpc.Fault(code=101,
+                            message="Indentation error")
         starting_offset = self.codeassist.starting_offset(source, offset)
         prefixlen = offset - starting_offset
         return [[proposal.name[prefixlen:], proposal.get_doc()]
@@ -158,7 +162,7 @@ class RopeBackend(NativeBackend):
             return self.codeassist.get_calltip(project, source, offset,
                                                resource, MAXFIXES,
                                                remove_self=True)
-        except self.ModuleSyntaxError:
+        except (self.ModuleSyntaxError, IndentationError):
             return None
         except (self.BadIdentifierError, IndexError):
             # IndexError seems to be a bug in Rope. I don't know what
